=== modified file 'drizzled/common_fwd.h'
--- drizzled/common_fwd.h	2011-04-29 00:19:38 +0000
+++ drizzled/common_fwd.h	2011-04-29 16:12:27 +0000
@@ -55,7 +55,7 @@
 
 namespace internal
 {
-  struct st_io_cache;
+  struct io_cache_st;
   
   struct st_my_thread_var;
 }

=== modified file 'drizzled/filesort_info.h'
--- drizzled/filesort_info.h	2011-03-14 05:40:28 +0000
+++ drizzled/filesort_info.h	2011-04-29 16:12:27 +0000
@@ -28,7 +28,7 @@
 class filesort_info
 {
 public:
-  internal::st_io_cache *io_cache;           /* If sorted through filesort */
+  internal::io_cache_st *io_cache;           /* If sorted through filesort */
   unsigned char     **sort_keys;        /* Buffer for sorting keys */
   unsigned char     *buffpek;           /* Buffer for buffpek structures */
   uint32_t      buffpek_len;        /* Max number of buffpeks in the buffer */

=== modified file 'drizzled/internal/iocache.cc'
--- drizzled/internal/iocache.cc	2011-02-17 00:14:13 +0000
+++ drizzled/internal/iocache.cc	2011-04-29 16:12:27 +0000
@@ -29,14 +29,14 @@
 {
 
 /*
-** Open tempfile cached by st_io_cache
+** Open tempfile cached by io_cache_st
 ** Should be used when no seeks are done (only reinit_io_buff)
 ** Return false if cache is inited ok
-** The actual file is created when the st_io_cache buffer gets filled
+** The actual file is created when the io_cache_st buffer gets filled
 ** If dir is not given, use TMPDIR.
 */
 
-bool st_io_cache::open_cached_file(const char *dir_arg, const char *prefix_arg,
+bool io_cache_st::open_cached_file(const char *dir_arg, const char *prefix_arg,
 		      size_t cache_size_arg, myf cache_myflags)
 {
   dir=	 dir_arg ? strdup(dir_arg) : (char*) 0;
@@ -59,7 +59,7 @@
 
 /* Create the temporary file */
 
-bool st_io_cache::real_open_cached_file()
+bool io_cache_st::real_open_cached_file()
 {
   char name_buff[FN_REFLEN];
 
@@ -73,7 +73,7 @@
 }
 
 
-void st_io_cache::close_cached_file()
+void io_cache_st::close_cached_file()
 {
   if (my_b_inited(this))
   {

=== modified file 'drizzled/internal/iocache.h'
--- drizzled/internal/iocache.h	2011-04-29 00:19:38 +0000
+++ drizzled/internal/iocache.h	2011-04-29 16:12:27 +0000
@@ -27,10 +27,10 @@
 namespace internal
 {
 
-struct st_io_cache;
-typedef int (*IO_CACHE_CALLBACK)(struct st_io_cache*);
+struct io_cache_st;
+typedef int (*IO_CACHE_CALLBACK)(struct io_cache_st*);
 
-struct st_io_cache    /* Used when cacheing files */
+struct io_cache_st    /* Used when cacheing files */
 {
   /* Offset in file corresponding to the first byte of unsigned char* buffer. */
   my_off_t pos_in_file;
@@ -77,12 +77,12 @@
     my_b_read() will call read_function to fetch the data. read_function
     must never be invoked directly.
   */
-  int (*read_function)(struct st_io_cache *,unsigned char *,size_t);
+  int (*read_function)(struct io_cache_st *,unsigned char *,size_t);
   /*
     Same idea as in the case of read_function, except my_b_write() needs to
     be replaced with my_b_append() for a SEQ_READ_APPEND cache
   */
-  int (*write_function)(struct st_io_cache *,const unsigned char *,size_t);
+  int (*write_function)(struct io_cache_st *,const unsigned char *,size_t);
   /*
     Specifies the type of the cache. Depending on the type of the cache
     certain operations might not be available and yield unpredicatable
@@ -97,9 +97,9 @@
     when io_cache_st is closed, we create an end event. These functions could,
     of course be used for other things
   */
-  io_cache_st_CALLBACK pre_read;
-  io_cache_st_CALLBACK post_read;
-  io_cache_st_CALLBACK pre_close;
+  IO_CACHE_CALLBACK pre_read;
+  IO_CACHE_CALLBACK post_read;
+  IO_CACHE_CALLBACK pre_close;
   void* arg;        /* for use by pre/post_read */
   char *file_name;      /* if used with 'open_cached_file' */
   char *dir,*prefix;
@@ -125,7 +125,7 @@
   */
   bool alloced_buffer;
 
-  st_io_cache() :
+  io_cache_st() :
     pos_in_file(0),
     end_of_file(0),
     read_pos(0),
@@ -157,7 +157,7 @@
     alloced_buffer(0)
   { }
 
-  ~st_io_cache()
+  ~io_cache_st()
   { }
 
   void close_cached_file();
@@ -179,14 +179,14 @@
 
 };
 
-typedef struct st_io_cache IO_CACHE;    /* Used when cacheing files */
-
-extern int _my_b_get(st_io_cache *info);
-extern int _my_b_async_read(st_io_cache *info,unsigned char *Buffer,size_t Count);
-
-extern int my_block_write(st_io_cache *info, const unsigned char *Buffer,
+typedef struct io_cache_st IO_CACHE;    /* Used when cacheing files */
+
+extern int _my_b_get(io_cache_st *info);
+extern int _my_b_async_read(io_cache_st *info,unsigned char *Buffer,size_t Count);
+
+extern int my_block_write(io_cache_st *info, const unsigned char *Buffer,
                           size_t Count, my_off_t pos);
-extern int my_b_flush_io_cache(st_io_cache *info, int need_append_buffer_lock);
+extern int my_b_flush_io_cache(io_cache_st *info, int need_append_buffer_lock);
 
 #define flush_io_cache(info) my_b_flush_io_cache((info),1)
 

=== modified file 'drizzled/internal/mf_iocache.cc'
--- drizzled/internal/mf_iocache.cc	2011-04-29 00:19:38 +0000
+++ drizzled/internal/mf_iocache.cc	2011-04-29 16:12:27 +0000
@@ -68,24 +68,24 @@
 namespace internal
 {
 
-static int _my_b_read(st_io_cache *info, unsigned char *Buffer, size_t Count);
-static int _my_b_write(st_io_cache *info, const unsigned char *Buffer, size_t Count);
+static int _my_b_read(io_cache_st *info, unsigned char *Buffer, size_t Count);
+static int _my_b_write(io_cache_st *info, const unsigned char *Buffer, size_t Count);
 
 /**
  * @brief
- *   Lock appends for the st_io_cache if required (need_append_buffer_lock)   
+ *   Lock appends for the io_cache_st if required (need_append_buffer_lock)   
  */
 inline
-static void lock_append_buffer(st_io_cache *, int )
+static void lock_append_buffer(io_cache_st *, int )
 {
 }
 
 /**
  * @brief
- *   Unlock appends for the st_io_cache if required (need_append_buffer_lock)   
+ *   Unlock appends for the io_cache_st if required (need_append_buffer_lock)   
  */
 inline
-static void unlock_append_buffer(st_io_cache *, int )
+static void unlock_append_buffer(io_cache_st *, int )
 {
 }
 
@@ -112,15 +112,15 @@
 
 /**
  * @brief 
- *   Setup internal pointers inside st_io_cache
+ *   Setup internal pointers inside io_cache_st
  * 
  * @details
- *   This is called on automatically on init or reinit of st_io_cache
- *   It must be called externally if one moves or copies an st_io_cache object.
+ *   This is called on automatically on init or reinit of io_cache_st
+ *   It must be called externally if one moves or copies an io_cache_st object.
  * 
  * @param info Cache handler to setup
  */
-void st_io_cache::setup_io_cache()
+void io_cache_st::setup_io_cache()
 {
   /* Ensure that my_b_tell() and my_b_bytes_in_cache works */
   if (type == WRITE_CACHE)
@@ -136,7 +136,7 @@
 }
 
 
-void st_io_cache::init_functions()
+void io_cache_st::init_functions()
 {
   switch (type) {
   case READ_NET:
@@ -158,7 +158,7 @@
 
 /**
  * @brief
- *   Initialize an st_io_cache object
+ *   Initialize an io_cache_st object
  *
  * @param file File that should be associated with the handler
  *                 If == -1 then real_open_cached_file() will be called when it's time to open file.
@@ -173,7 +173,7 @@
  * @retval 0 success
  * @retval # error
  */
-int st_io_cache::init_io_cache(int file_arg, size_t cachesize,
+int io_cache_st::init_io_cache(int file_arg, size_t cachesize,
                                enum cache_type type_arg, my_off_t seek_offset,
                                bool use_async_io, myf cache_myflags)
 {
@@ -297,7 +297,7 @@
  *   If we are doing a reinit of a cache where we have the start of the file
  *   in the cache, we are reusing this memory without flushing it to disk.
  */
-bool st_io_cache::reinit_io_cache(enum cache_type type_arg,
+bool io_cache_st::reinit_io_cache(enum cache_type type_arg,
                                   my_off_t seek_offset,
                                   bool,
                                   bool clear_cache)
@@ -385,13 +385,13 @@
  *   types than my_off_t unless you can be sure that their value fits.
  *   Same applies to differences of file offsets.
  *
- * @param info st_io_cache pointer @param Buffer Buffer to retrieve count bytes
+ * @param info io_cache_st pointer @param Buffer Buffer to retrieve count bytes
  * from file @param Count Number of bytes to read into Buffer
  * 
  * @retval 0 We succeeded in reading all data
  * @retval 1 Error: can't read requested characters
  */
-static int _my_b_read(st_io_cache *info, unsigned char *Buffer, size_t Count)
+static int _my_b_read(io_cache_st *info, unsigned char *Buffer, size_t Count)
 {
   size_t length_local,diff_length,left_length, max_length;
   my_off_t pos_in_file_local;
@@ -408,10 +408,10 @@
   pos_in_file_local=info->pos_in_file+ (size_t) (info->read_end - info->buffer);
 
   /*
-    Whenever a function which operates on st_io_cache flushes/writes
-    some part of the st_io_cache to disk it will set the property
+    Whenever a function which operates on io_cache_st flushes/writes
+    some part of the io_cache_st to disk it will set the property
     "seek_not_done" to indicate this to other functions operating
-    on the st_io_cache.
+    on the io_cache_st.
   */
   if (info->seek_not_done)
   {
@@ -491,28 +491,32 @@
  * @brief
  *   Read one byte when buffer is empty
  */
-int _my_b_get(st_io_cache *info)
+int _my_b_get(io_cache_st *info)
 {
   unsigned char buff;
-  io_cache_st_CALLBACK pre_read,post_read;
+  IO_CACHE_CALLBACK pre_read,post_read;
+
   if ((pre_read = info->pre_read))
     (*pre_read)(info);
+
   if ((*(info)->read_function)(info,&buff,1))
     return my_b_EOF;
+
   if ((post_read = info->post_read))
     (*post_read)(info);
+
   return (int) (unsigned char) buff;
 }
 
 /**
  * @brief
- *   Write a byte buffer to st_io_cache and flush to disk if st_io_cache is full.
+ *   Write a byte buffer to io_cache_st and flush to disk if io_cache_st is full.
  *
  * @retval -1 On error; errno contains error code.
  * @retval 0 On success
  * @retval 1 On error on write
  */
-int _my_b_write(st_io_cache *info, const unsigned char *Buffer, size_t Count)
+int _my_b_write(io_cache_st *info, const unsigned char *Buffer, size_t Count)
 {
   size_t rest_length,length_local;
 
@@ -536,10 +540,10 @@
     if (info->seek_not_done)
     {
       /*
-        Whenever a function which operates on st_io_cache flushes/writes
-        some part of the st_io_cache to disk it will set the property
+        Whenever a function which operates on io_cache_st flushes/writes
+        some part of the io_cache_st to disk it will set the property
         "seek_not_done" to indicate this to other functions operating
-        on the st_io_cache.
+        on the io_cache_st.
       */
       if (lseek(info->file,info->pos_in_file,SEEK_SET))
       {
@@ -566,7 +570,7 @@
  *   As all write calls to the data goes through the cache,
  *   we will never get a seek over the end of the buffer.
  */
-int my_block_write(st_io_cache *info, const unsigned char *Buffer, size_t Count,
+int my_block_write(io_cache_st *info, const unsigned char *Buffer, size_t Count,
 		   my_off_t pos)
 {
   size_t length_local;
@@ -613,7 +617,7 @@
  * @brief
  *   Flush write cache 
  */
-int my_b_flush_io_cache(st_io_cache *info, int need_append_buffer_lock)
+int my_b_flush_io_cache(io_cache_st *info, int need_append_buffer_lock)
 {
   size_t length_local;
   bool append_cache= false;
@@ -677,19 +681,19 @@
 
 /**
  * @brief
- *   Free an st_io_cache object
+ *   Free an io_cache_st object
  * 
  * @detail
  *   It's currently safe to call this if one has called init_io_cache()
  *   on the 'info' object, even if init_io_cache() failed.
  *   This function is also safe to call twice with the same handle.
  * 
- * @param info st_io_cache Handle to free
+ * @param info io_cache_st Handle to free
  * 
  * @retval 0 ok
  * @retval # Error
  */
-int st_io_cache::end_io_cache()
+int io_cache_st::end_io_cache()
 {
   int _error=0;
 

